@@ -1,8 +1,14 @@
+import calendar
+import datetime
 import logging
 import os
 import random
 import re
 import string
+import time
+import traceback
+from collections import Counter
+from distutils.sysconfig import PREFIX
 
 import bbcloud_python_sdk
 import oss2 as oss2
@@ -85,3 +91,42 @@ class OssFileCache():
             self.bucket.delete_object(cache_path)
         except oss2.exceptions.NoSuchKey:
             return False
+
+    def list_cache_objects(self):
+        """
+        获取文件夹OSS缓存文件
+        @param key:
+        """
+        prefix_path = "%s/%s" % (self.cache_path_root, self.namespace)
+        list_dir = []
+        marker = ''
+        begin = False
+        while (marker != '') or (not begin):
+            list_objects = self.bucket.list_objects(prefix=prefix_path, max_keys=100, marker=marker)
+            marker = list_objects.next_marker
+            begin = True
+            for i in list_objects.object_list:
+                list_dir.append(i)
+        return list_dir
+
+    def list_dir(self, deep_num):
+        prefix_path = "%s/%s" % (self.cache_path_root, self.namespace)
+        all_list_dir = []
+        one_list_dir = []
+        marker = ''
+        begin = False
+        while (marker != '') or (not begin):
+            list_objects = self.bucket.list_objects(prefix=prefix_path, max_keys=100, marker=marker)
+            marker = list_objects.next_marker
+            begin = True
+            for i in list_objects.object_list:
+                all_list_dir.append(i.key.rsplit("/", 1)[0])
+        for data in all_list_dir:
+            tmp_dir = data.rsplit("/", len(data.split('/')) - len(prefix_path.split('/')) - deep_num)[0]
+            if tmp_dir not in one_list_dir:
+                one_list_dir.append(tmp_dir)
+        if self.cache_path_root in one_list_dir:
+            one_list_dir.remove(self.cache_path_root)
+        if prefix_path in one_list_dir:
+            one_list_dir.remove(prefix_path)
+        return one_list_dir
