@@ -105,3 +105,11 @@ class FileCache():
             return True
         else:
             return self.default_engine.set_namespace(namespace=self.namespace).delete(key=key)
+
+    @runtime_logging
+    def list_cache_objects(self):
+        return self.default_engine.set_namespace(namespace=self.namespace).list_cache_objects()
+
+    @runtime_logging
+    def list_dir(self, deep_num):
+        return self.default_engine.set_namespace(namespace=self.namespace).list_dir(deep_num=deep_num)
